@@ -27,4 +27,6 @@ def status(ctx, is_raw):
         click.echo("Success!\n\nAPI deployment information:")
         print_table(svc.build_info)
 
+        svc = ctx.obj.service
+        click.echo("{0:20}{1}".format("Current project", svc.project))
         click.echo('')
