@@ -36,7 +36,7 @@ def write_instance_metrics_plot(
         click.echo("Please install with 'brew reinstall gnuplot --with-cairo'")
         sys.exit(1)
     proc = subprocess.Popen(
-        ['gnuplot', '-p'], shell=True, stdin=subprocess.PIPE, close_fds=True  # Ignore B602
+        ['gnuplot', '-p'], shell=False, stdin=subprocess.PIPE, close_fds=True  # Ignore B602
     )
     file_name = os.path.expanduser('~/job_%s.png' % job_id)
     try:
